@@ -46,6 +46,33 @@ class DBConnect:
                 other={'prompt': str(err)}
             )
 
+    def write_many_docu(self, docu_list: list) -> list:
+        try:
+            new_docu_list = []
+            for docu in docu_list:
+                if isinstance(docu, dict):
+                    # 添加创建时间和更新时间，日期格式
+                    if not docu.__contains__('creation_time'):
+                        docu['creation_time'] = datetime.today()
+                    if not docu.__contains__('update_time'):
+                        docu['update_time'] = datetime.today()
+                    new_docu_list.append(docu)
+                else:
+                    handle_abnormal(
+                        message='参数docu_list格式不正确，要求为：[{},{},{}...]',
+                        status=500,
+                        other={'prompt': {'docu_list': docu_list}}
+                    )
+                new_data_list = self.mongo_collection.insert_many(new_docu_list)
+                new_id_list = [str(_id) for _id in new_data_list.inserted_ids]
+                return new_id_list
+        except Exception as err:
+            handle_abnormal(
+                message='MongoDB(组件)出现写入错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
+
     def does_it_exist(self, docu: dict) -> bool:
         count = self.mongo_collection.count_documents(docu)
         if count != 0:
@@ -63,7 +90,7 @@ class DBConnect:
             if not modify_docu.__contains__('update_time'):
                 modify_docu['update_time'] = datetime.today()
             # 将更新内容转化为mongo能识别的更新格式
-            modify_docu = {'$set':modify_docu}
+            modify_docu = {'$set': modify_docu}
             if many:
                 student = self.mongo_collection.update_many(
                     find_docu, modify_docu)
