@@ -5,6 +5,7 @@ from .tools import handle_abnormal
 
 class Parameter():
     def __init__(self, request):
+        self.request = request
         self.method = request.method  # 请求方法
         self.headers = dict(request.headers)  # 请求头
         # GET方法的取参
@@ -63,3 +64,36 @@ class Parameter():
                     other={'prompt': str(err)}
                 )
         return checking
+
+    def verification_file(self, verify_field: list, verify_suffix: list = []):
+        files = self.request.files
+        for field in verify_field:
+            if not files.get(field, None):
+                handle_abnormal(
+                    message='表单文件参数不完整',
+                    status=400,
+                    other={'prompt': verify_field}
+                )
+        if verify_suffix:
+            if len(verify_suffix) != len(verify_field):
+                handle_abnormal(
+                    message='参数 verify_field 与 verify_suffix 的长度不一致',
+                    status=500,
+                )
+            for i in range(len(verify_suffix)):
+                file_name = files[verify_field[i]].filename
+                if type(verify_suffix[i]) == list:
+                    if file_name.split('.')[-1] not in verify_suffix[i]:
+                        handle_abnormal(
+                            message='文件字段 {0} 仅支持 {1} 后缀'.format(
+                                verify_field[i], verify_suffix[i]),
+                            status=400,
+                        )
+                else:
+                    if file_name.split('.')[-1] != verify_suffix[i]:
+                        handle_abnormal(
+                            message='文件字段 {0} 仅支持 {1} 后缀'.format(
+                                verify_field[i], verify_suffix[i]),
+                            status=400,
+                        )
+        return files
