@@ -56,7 +56,8 @@ def handle_db_dict(db_dict: dict) -> dict:
         db_dict['id'] = str(db_dict['_id'])
         del db_dict['_id']
         # 创建时间和更新时间如果不存在，则设置为当前时间
-        db_dict['creation_time'] = db_dict.get('creation_time', datetime.today())
+        db_dict['creation_time'] = db_dict.get(
+            'creation_time', datetime.today())
         db_dict['update_time'] = db_dict.get('update_time', datetime.today())
         # 将日期格式的时间，转化为13位时间戳
         db_dict['creation_time'] = int(time.mktime(
@@ -125,3 +126,33 @@ def handle_abnormal(message: str, status: int, header: dict = {'Content-Type': '
         return return_body, status, header
     else:
         abort(Response(json.dumps(return_body), status, header))
+
+
+def handle_download_file(file_path: str, file_name: str):
+    response = make_response(send_from_directory(
+        file_path,  # 本地目录的path
+        file_name,  # 文件名(带扩展名)
+        as_attachment=True
+    ))
+    response.headers['Content-Disposition'] = 'attachment; filename={}'.format(
+        file_name.encode().decode('latin-1'))
+    return response
+
+
+def handle_download_flow(file_path: str, file_name: str):
+    complete_path = os.path.join(file_path, file_name)
+    # 流式读取文件
+
+    def send_file():
+        with open(complete_path, 'rb') as target_file:
+            while 1:
+                data = target_file.read(20 * 1024 * 1024)   # 每次读取20M
+                if not data:
+                    break
+                yield data
+    # 浏览器不识别的也会自动下载
+    response = Response(send_file(), content_type='application/octet-stream')
+    # 确保中文格式不乱码
+    response.headers['Content-Disposition'] = 'attachment; filename={}'.format(
+        file_name.encode().decode('latin-1'))
+    return response
